==> haskell-shakespeare-2.0.8.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-shakespeare/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.8.2
id: shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
key: shake_JiUTC8JfMMi93OhWtxHxIf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.8.2
hs-libraries: HSshakespeare-2.0.8.2-JiUTC8JfMMi93OhWtxHxIf
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.8.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-shakespeare/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.8.2
id: shakespeare-2.0.8.2-b321569ec5295e19a9b3f8b5ef85b2ad
key: shake_5ctodLvSujNFyIHrITgMkT
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.8.2
hs-libraries: HSshakespeare-2.0.8.2-5ctodLvSujNFyIHrITgMkT
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
